@@ -4,14 +4,14 @@
 "log1pexp", "phi", "pnorm", "normcdf", "qnorm", "fabs", "pow", 
 "R_pow", "R_pow_di", "Rx_pow_di", "Rx_pow", "lbeta", "abs", "acos", 
 "acosh", "asin", "asinh", "atan", "atan2", "atanh", "beta", "cos", 
-"cosh", "erf", "erfc", "exp", "gamma", "linCmtA", "linCmtC", 
-"linCmtB", "log", "polygamma", "rxTBS", "rxTBSi", "rxTBSd", "rxTBSd2", 
-"sin", "sinh", "sqrt", "tan", "tanh", "gammap", "floor", "round", 
-"ceil", "trunc", "bessel_i", "bessel_j", "bessel_k", "bessel_y", 
-"logspace_add", "logspace_sub", "fmax2", "fmin2", "sign", "fsign", 
-"fprec", "fround", "ftrunc", "transit", "gammaq", "gammapDer", 
-"gammapInv", "gammapInva", "gammaqInv", "gammaqInva", "lowergamma", 
-"uppergamma", "max", "min", "logit", "expit", "probit", "probitInv", 
+"cosh", "erf", "erfc", "exp", "gamma", "log", "polygamma", "rxTBS", 
+"rxTBSi", "rxTBSd", "rxTBSd2", "sin", "sinh", "sqrt", "tan", 
+"tanh", "gammap", "floor", "round", "ceil", "trunc", "bessel_i", 
+"bessel_j", "bessel_k", "bessel_y", "logspace_add", "logspace_sub", 
+"fmax2", "fmin2", "sign", "fsign", "fprec", "fround", "ftrunc", 
+"transit", "gammaq", "gammapDer", "gammapInv", "gammapInva", 
+"gammaqInv", "gammaqInva", "lowergamma", "uppergamma", "linCmtA", 
+"linCmtB", "max", "min", "logit", "expit", "probit", "probitInv", 
 "tlast", "tlast0", "tfirst", "tfirst0", "lag", "lead", "dose", 
 "podo", "dose0", "podo0", "dabs", "dabs2", "abs1", "dabs1", "erfinv", 
 "abs0", "dosenum", "first", "last", "diff", "is.nan", "is.na", 
@@ -43,39 +43,38 @@
 "rxpois", "rpois", "rxt", "rt")
 .parseEnv$.parseNum <- c(lgamma = 1, abs = 1, acos = 1, acosh = 1, asin = 1, asinh = 1, 
 atan = 1, atan2 = 2, atanh = 1, beta = 2, cos = 1, cosh = 1, 
-erf = 1, erfc = 1, exp = 1, gamma = 1, linCmtA = 20, linCmtC = 20, 
-linCmtB = 21, log = 1, polygamma = 2, rxTBS = 5, rxTBSi = 5, 
-rxTBSd = 5, rxTBSd2 = 5, sin = 1, sinh = 1, sqrt = 1, tan = 1, 
-tanh = 1, gammap = 2, floor = 1, round = 1, ceil = 1, trunc = 1, 
-bessel_i = 3, bessel_j = 2, bessel_k = 3, bessel_y = 2, logspace_add = 2, 
-logspace_sub = 2, fmax2 = 2, fmin2 = 2, sign = 1, fsign = 2, 
-fprec = 2, fround = 2, ftrunc = 2, transit = NA, gammaq = 2, 
-gammapDer = 2, gammapInv = 2, gammapInva = 2, gammaqInv = 2, 
-gammaqInva = 2, lowergamma = 2, uppergamma = 2, max = NA, min = NA, 
-logit = NA, expit = NA, probit = NA, probitInv = NA, tlast = NA, 
-tlast0 = NA, tfirst = NA, tfirst0 = NA, lag = NA, lead = NA, 
-dose = NA, podo = NA, dose0 = NA, podo0 = NA, dabs = 1, dabs2 = 1, 
-abs1 = 1, dabs1 = 1, erfinv = 1, abs0 = 1, dosenum = 0, first = 1, 
-last = 1, diff = 1, is.nan = 1, is.na = 1, is.finite = 1, is.infinite = 1, 
-llikPois = 2, llikPoisDlambda = 2, llikBinom = 3, llikBinomDprob = 3, 
-llikNbinom = 3, llikNbinomDprob = 3, llikNbinomMu = 3, llikNbinomMuDmu = 3, 
-llikBeta = 3, llikBetaDshape1 = 3, llikBetaDshape2 = 3, llikT = 4, 
-llikTDdf = 4, llikTDmean = 4, llikTDsd = 4, llikChisq = 2, llikChisqDdf = 2, 
-llikExp = 2, llikExpDrate = 2, llikF = 3, llikFDdf1 = 3, llikFDdf2 = 3, 
-llikGeom = 2, llikGeomDprob = 2, llikUnif = 3, llikUnifDalpha = 3, 
-llikUnifDbeta = 3, llikWeibull = 3, llikWeibullDshape = 3, llikWeibullDscale = 3, 
-llikGamma = 3, llikGammaDshape = 3, llikGammaDrate = 3, llikCauchy = 3, 
-llikCauchyDlocation = 3, llikCauchyDscale = 3, llikNorm = 3, 
-llikNormDmean = 3, llikNormDsd = 3, llikXPois = 3, llikXPoisDlambda = 3, 
-llikXBinom = 4, llikXBinomDprob = 4, llikXNbinomMu = 4, llikXNbinomMuDmu = 4, 
-llikXNbinom = 4, llikXNbinomDprob = 4, llikXBeta = 4, llikXBetaDshape1 = 4, 
-llikXBetaDshape2 = 4, llikXT = 5, llikXTDdf = 5, llikXTDmean = 5, 
-llikXTDsd = 5, llikXChisq = 3, llikXChisqDdf = 3, llikXExp = 3, 
-llikXExpDrate = 3, llikXF = 4, llikXFDdf1 = 4, llikXFDdf2 = 4, 
-llikXGeom = 3, llikXGeomDprob = 3, llikXUnif = 4, llikXUnifDalpha = 4, 
-llikXUnifDbeta = 4, llikXWeibull = 4, llikXWeibullDshape = 4, 
-llikXWeibullDscale = 4, llikXGamma = 4, llikXGammaDshape = 4, 
-llikXGammaDrate = 4, llikXCauchy = 4, llikXCauchyDlocation = 4, 
+erf = 1, erfc = 1, exp = 1, gamma = 1, log = 1, polygamma = 2, 
+rxTBS = 5, rxTBSi = 5, rxTBSd = 5, rxTBSd2 = 5, sin = 1, sinh = 1, 
+sqrt = 1, tan = 1, tanh = 1, gammap = 2, floor = 1, round = 1, 
+ceil = 1, trunc = 1, bessel_i = 3, bessel_j = 2, bessel_k = 3, 
+bessel_y = 2, logspace_add = 2, logspace_sub = 2, fmax2 = 2, 
+fmin2 = 2, sign = 1, fsign = 2, fprec = 2, fround = 2, ftrunc = 2, 
+transit = NA, gammaq = 2, gammapDer = 2, gammapInv = 2, gammapInva = 2, 
+gammaqInv = 2, gammaqInva = 2, lowergamma = 2, uppergamma = 2, 
+linCmtA = 14, linCmtB = 15, max = NA, min = NA, logit = NA, expit = NA, 
+probit = NA, probitInv = NA, tlast = NA, tlast0 = NA, tfirst = NA, 
+tfirst0 = NA, lag = NA, lead = NA, dose = NA, podo = NA, dose0 = NA, 
+podo0 = NA, dabs = 1, dabs2 = 1, abs1 = 1, dabs1 = 1, erfinv = 1, 
+abs0 = 1, dosenum = 0, first = 1, last = 1, diff = 1, is.nan = 1, 
+is.na = 1, is.finite = 1, is.infinite = 1, llikPois = 2, llikPoisDlambda = 2, 
+llikBinom = 3, llikBinomDprob = 3, llikNbinom = 3, llikNbinomDprob = 3, 
+llikNbinomMu = 3, llikNbinomMuDmu = 3, llikBeta = 3, llikBetaDshape1 = 3, 
+llikBetaDshape2 = 3, llikT = 4, llikTDdf = 4, llikTDmean = 4, 
+llikTDsd = 4, llikChisq = 2, llikChisqDdf = 2, llikExp = 2, llikExpDrate = 2, 
+llikF = 3, llikFDdf1 = 3, llikFDdf2 = 3, llikGeom = 2, llikGeomDprob = 2, 
+llikUnif = 3, llikUnifDalpha = 3, llikUnifDbeta = 3, llikWeibull = 3, 
+llikWeibullDshape = 3, llikWeibullDscale = 3, llikGamma = 3, 
+llikGammaDshape = 3, llikGammaDrate = 3, llikCauchy = 3, llikCauchyDlocation = 3, 
+llikCauchyDscale = 3, llikNorm = 3, llikNormDmean = 3, llikNormDsd = 3, 
+llikXPois = 3, llikXPoisDlambda = 3, llikXBinom = 4, llikXBinomDprob = 4, 
+llikXNbinomMu = 4, llikXNbinomMuDmu = 4, llikXNbinom = 4, llikXNbinomDprob = 4, 
+llikXBeta = 4, llikXBetaDshape1 = 4, llikXBetaDshape2 = 4, llikXT = 5, 
+llikXTDdf = 5, llikXTDmean = 5, llikXTDsd = 5, llikXChisq = 3, 
+llikXChisqDdf = 3, llikXExp = 3, llikXExpDrate = 3, llikXF = 4, 
+llikXFDdf1 = 4, llikXFDdf2 = 4, llikXGeom = 3, llikXGeomDprob = 3, 
+llikXUnif = 4, llikXUnifDalpha = 4, llikXUnifDbeta = 4, llikXWeibull = 4, 
+llikXWeibullDshape = 4, llikXWeibullDscale = 4, llikXGamma = 4, 
+llikXGammaDshape = 4, llikXGammaDrate = 4, llikXCauchy = 4, llikXCauchyDlocation = 4, 
 llikXCauchyDscale = 4, llikXNorm = 4, llikXNormDmean = 4, llikXNormDsd = 4, 
 ReLU = 1, dReLU = 1, GELU = 1, dGELU = 1, d2GELU = 1, d3GELU = 1, 
 d4GELU = 1, ELU = 2, dELU = 2, d2ELU = 2, d2aELU = 2, dELUa = 2, 
