@@ -19,12 +19,42 @@ rxode2_fn0i _sumType = NULL;
 _update_par_ptr_p _update_par_ptr=NULL;
 _getParCov_p _getParCov=NULL;
 linCmtA_p linCmtA;
-linCmtA_p linCmtC;
 linCmtB_p linCmtB;
 _rx_asgn _rxode2_rxAssignPtr =NULL;
 _rx_asgn _rxQr =NULL;
 
 rxode2_fn phi;
+rxode2_fn ReLU;
+rxode2_fn dReLU;
+rxode2_fn GELU;
+rxode2_fn dGELU;
+rxode2_fn d2GELU;
+rxode2_fn d3GELU;
+rxode2_fn d4GELU;
+rxode2_fn softplus;
+rxode2_fn dsoftplus;
+rxode2_fn d2softplus;
+rxode2_fn d3softplus;
+rxode2_fn d4softplus;
+rxode2_fn SELU;
+rxode2_fn dSELU;
+rxode2_fn lReLU;
+rxode2_fn dlReLU;
+rxode2_fn Swish;
+rxode2_fn dSwish;
+
+rxode2_fn2 PReLU;
+rxode2_fn2 dPReLU;
+rxode2_fn2 dPReLUa;
+rxode2_fn2 dPReLUa1;
+
+rxode2_fn2 ELU;
+rxode2_fn2 dELU;
+rxode2_fn2 d2ELU;
+rxode2_fn2 d2aELU;
+rxode2_fn2 dELUa;
+rxode2_fn2 d2ELUa;
+
 rxode2_fn3 logit;
 rxode2_fn3 expit;
 rxode2_fn2 gammap;
@@ -278,8 +308,6 @@ void _assignFuns0(void) {
   // dynamic start
   linCmtA=(linCmtA_p)R_GetCCallable("rxode2", "linCmtA");
   linCmtB=(linCmtB_p)R_GetCCallable("rxode2", "linCmtB");
-  linCmtC=(linCmtA_p)R_GetCCallable("rxode2", "linCmtC");
-
   rxnorm = (rxode2i_fn2)R_GetCCallable("rxode2", "rxnorm");
   rxbinom = (rxode2i_rxbinom)R_GetCCallable("rxode2","rxbinom");
   rxnbinom = (rxode2i_rxbinom)R_GetCCallable("rxode2","rxnbinom");
@@ -310,6 +338,34 @@ void _assignFuns0(void) {
   rit_ = (rxode2i2_fn)R_GetCCallable("rxode2","rit_");
   riunif = (rxode2i2_fn2)R_GetCCallable("rxode2","riunif");
   riweibull = (rxode2i2_fn2)R_GetCCallable("rxode2","riweibull");
+  ReLU = (rxode2_fn)R_GetCCallable("rxode2","ReLU");
+  dReLU = (rxode2_fn)R_GetCCallable("rxode2","dReLU");
+  GELU = (rxode2_fn)R_GetCCallable("rxode2","GELU");
+  dGELU = (rxode2_fn)R_GetCCallable("rxode2","dGELU");
+  d2GELU = (rxode2_fn)R_GetCCallable("rxode2","d2GELU");
+  d3GELU = (rxode2_fn)R_GetCCallable("rxode2","d3GELU");
+  d4GELU = (rxode2_fn)R_GetCCallable("rxode2","d4GELU");
+  softplus = (rxode2_fn)R_GetCCallable("rxode2","softplus");
+  dsoftplus = (rxode2_fn)R_GetCCallable("rxode2","dsoftplus");
+  d2softplus = (rxode2_fn)R_GetCCallable("rxode2","d2softplus");
+  d3softplus = (rxode2_fn)R_GetCCallable("rxode2","d3softplus");
+  d4softplus = (rxode2_fn)R_GetCCallable("rxode2","d4softplus");
+  SELU = (rxode2_fn)R_GetCCallable("rxode2","SELU");
+  dSELU = (rxode2_fn)R_GetCCallable("rxode2","dSELU");
+  lReLU = (rxode2_fn)R_GetCCallable("rxode2","lReLU");
+  dlReLU = (rxode2_fn)R_GetCCallable("rxode2","dlReLU");
+  Swish = (rxode2_fn)R_GetCCallable("rxode2","Swish");
+  dSwish = (rxode2_fn)R_GetCCallable("rxode2","dSwish");
+  PReLU = (rxode2_fn2)R_GetCCallable("rxode2","PReLU");
+  dPReLU = (rxode2_fn2)R_GetCCallable("rxode2","dPReLU");
+  dPReLUa = (rxode2_fn2)R_GetCCallable("rxode2","dPReLUa");
+  dPReLUa1 = (rxode2_fn2)R_GetCCallable("rxode2","dPReLUa1");
+  ELU = (rxode2_fn2)R_GetCCallable("rxode2","ELU");
+  dELU = (rxode2_fn2)R_GetCCallable("rxode2","dELU");
+  d2ELU = (rxode2_fn2)R_GetCCallable("rxode2","d2ELU");
+  d2aELU = (rxode2_fn2)R_GetCCallable("rxode2","d2aELU");
+  dELUa = (rxode2_fn2)R_GetCCallable("rxode2","dELUa");
+  d2ELUa = (rxode2_fn2)R_GetCCallable("rxode2","d2ELUa");
   phi = (rxode2_fn)R_GetCCallable("rxode2","phi");
 
   gammap = (rxode2_fn2) R_GetCCallable("rxode2","gammap");
