@@ -13,13 +13,7 @@
 #include <R.h>
 #include <Rinternals.h>
 
-#ifdef ENABLE_NLS
-#include <libintl.h>
-#define _(String) dgettext ("rxode2", String)
-/* replace pkg as appropriate */
-#else
 #define _(String) (String)
-#endif
 
 static long int     nfcn, nstep, naccpt, nrejct;
 static double       hout, xold, xout;
