@@ -18,13 +18,7 @@
 #include <Rinternals.h>
 #include <R_ext/Rdynload.h>
 #include <Rmath.h>
-#ifdef ENABLE_NLS
-#include <libintl.h>
-#define _(String) dgettext ("rxode2parse", String)
-/* replace pkg as appropriate */
-#else
 #define _(String) (String)
-#endif
 
 // change the name of the iniDparser pointer
 #define iniDparserPtr _rxode2_iniDparserPtr
@@ -89,7 +83,7 @@ static inline void addSymbolStr(char *value) {
 
 
 sbuf sb, sbDt; /* buffer w/ current parsed & translated line */
-sbuf sbt;
+sbuf sbt, sbt2;
 
 sbuf firstErr;
 
@@ -257,6 +251,7 @@ void parseFree(int last) {
   sFree(&sb);
   sFree(&sbDt);
   sFree(&sbt);
+  sFree(&sbt2);
   sFree(&sbNrm);
   sFree(&sbExtra);
   sFree(&s_inits);
@@ -331,6 +326,7 @@ void reset(void) {
   sIniTo(&sb, MXSYM);
   sIniTo(&sbDt, MXDER);
   sIniTo(&sbt, SBUF_MXBUF);
+  sIniTo(&sbt2, SBUF_MXBUF);
   sIniTo(&sbNrm, SBUF_MXBUF);
   sIniTo(&sbExtra,SBUF_MXBUF);
   sIniTo(&_gbuf, 1024);
@@ -355,8 +351,10 @@ void reset(void) {
   lineIni(&(tb.str));
 
   tb.lh		= R_Calloc(MXSYM, int);
+  tb.lho    = R_Calloc(MXSYM, int);
   tb.interp	= R_Calloc(MXSYM, int);
   tb.interpC= 0;
+  tb.lhi    = 1;
   tb.ini	= R_Calloc(MXSYM, int);
   tb.mtime	= R_Calloc(MXSYM, int);
   tb.iniv	= R_Calloc(MXSYM, double);
@@ -395,6 +393,7 @@ void reset(void) {
   tb.isPi       = 0;
   tb.isNA       = 0;
   tb.linCmt     = 0;
+  tb.linCmtCmt  = 0;
   tb.linCmtN    = -100;
   tb.linCmtFlg  = 0;
   tb.df		= R_Calloc(MXSYM, int);
@@ -415,11 +414,11 @@ void reset(void) {
   tb.matn	= 0;
   tb.matnf	= 0;
   tb.ncmt	= 0;
+  tb.ndiff  = 0;
   tb.linB	= 0;
   tb.curPropN	= 0;
   tb.depotN	= -1;
   tb.centralN	= -1;
-  tb.linExtra   = false;
   tb.nwhile     = 0;
   tb.lvlStr     = 0;
   tb.dummyLhs   = 0;
@@ -579,14 +578,14 @@ static inline int setupTrans(SEXP parse_file, SEXP prefix, SEXP model_md5, SEXP
   set_d_rdebug_grammar_level(0);
   set_d_verbose_level(0);
 
-  if (isString(prefix) && Rf_length(prefix) == 1){
+  if (Rf_isString(prefix) && Rf_length(prefix) == 1){
     model_prefix = CHAR(STRING_ELT(prefix,0));
   } else {
     _rxode2parse_unprotect();
     err_trans("model prefix must be specified");
   }
 
-  if (isString(inME) && Rf_length(inME) == 1){
+  if (Rf_isString(inME) && Rf_length(inME) == 1){
     me_code = CHAR(STRING_ELT(inME,0));
   } else {
     freeP();
@@ -594,7 +593,7 @@ static inline int setupTrans(SEXP parse_file, SEXP prefix, SEXP model_md5, SEXP
     err_trans("extra ME code must be specified");
   }
 
-  if (isString(model_md5) && Rf_length(model_md5) == 1){
+  if (Rf_isString(model_md5) && Rf_length(model_md5) == 1){
     md5 = CHAR(STRING_ELT(model_md5,0));
     badMd5 = 0;
     if (strlen(md5)!= 32){
@@ -666,14 +665,13 @@ SEXP _rxode2_parseModel(SEXP type){
   case 1:
     pm = PROTECT(Rf_allocVector(STRSXP, sbPmDt.n));
     for (int i = 0; i < sbPmDt.n; i++){
-      SET_STRING_ELT(pm, i, mkChar(sbPmDt.line[i]));
+      SET_STRING_ELT(pm, i, Rf_mkChar(sbPmDt.line[i]));
     }
     break;
-
   default:
     pm = PROTECT(Rf_allocVector(STRSXP, sbPm.n));
     for (int i = 0; i < sbPm.n; i++){
-      SET_STRING_ELT(pm, i, mkChar(sbPm.line[i]));
+      SET_STRING_ELT(pm, i, Rf_mkChar(sbPm.line[i]));
     }
     break;
   }
@@ -722,6 +720,7 @@ void transIniNull(void) {
   sNull(&(sb));
   sNull(&(sbDt));
   sNull(&(sbt));
+  sNull(&(sbt2));
   sNull(&(firstErr));
   sNull(&(sbNrm));
   sNull(&(sbExtra));
@@ -737,3 +736,5 @@ void transIniNull(void) {
   sNull(&(_bufw2));
   lineNull(&(_dupStrs));
 }
+
+#include "parseLinCmtApplyCmts.h"
