@@ -19,6 +19,8 @@ rxTest({
 
       is.ini(as.ini(ini))
 
+      suppressMessages(expect_error(ini %>% ini(tka=3), NA))
+
       l <- quote(lotri({
         tka <- log(1.57)
         tcl <- log(2.72)
@@ -31,6 +33,8 @@ rxTest({
 
       is.ini(as.ini(l))
 
+      suppressMessages(expect_error(l %>% ini(tka=3), NA))
+
       m <- lotri({
         eta.ka ~ 0.6
         eta.cl ~ 0.3
@@ -39,6 +43,10 @@ rxTest({
 
       is.ini(as.ini(m))
 
+      suppressMessages(expect_error(m %>% ini(eta.ka=3), NA))
+
+      suppressMessages(expect_true(inherits(m %>% ini(eta.ka=3), "matrix")))
+
       one.compartment <- function() {
         ini({
           tka <- log(1.57)
@@ -80,10 +88,29 @@ rxTest({
 
       is.ini(as.ini(ini))
 
+      suppressMessages(expect_error(ini %>% ini(tka=3), NA))
+
+      suppressMessages(expect_true(inherits(ini %>% ini(tka=3) %>% lotri::as.lotri(.),
+                                            "lotriFix")))
+
       ini <- paste(ini, collapse="\n")
 
       is.ini(as.ini(ini))
 
+      suppressMessages(expect_error(ini %>% ini(tka=3), NA))
+
+      l <- lotri({
+        tka <- log(1.57)
+        tcl <- log(2.72)
+        tv <- log(31.5)
+        eta.ka ~ 0.6
+        eta.cl ~ 0.3
+        eta.v ~ 0.1
+        add.sd <- 0.7
+      })
+
+      suppressMessages(expect_error(l %>% ini(tka=3), NA))
+      suppressMessages(expect_true(inherits(l %>% ini(tka=3), "lotriFix")))
 
     })
   }
